@@ -118,7 +118,7 @@ class AirflowMesosScheduler(MesosClient):
        
     def resource_offers(self, offers):
         """If we got a offer, run a queued task"""
-        while (not self.task_queue.empty()):
+        if (not self.task_queue.empty()):
             for i, offer in enumerate(offers):
                 if not self.run_job(offer):
                      offertmp = offer.get_offer()
@@ -135,6 +135,9 @@ class AirflowMesosScheduler(MesosClient):
         offer_mem = 0
         force_pull = "true"
         container_type = "DOCKER"
+        cpu = self.task_cpu
+        mem = self.task_mem
+        image = self.mesos_slave_docker_image
         airflow_task_id = None
 
         for resource in offer["resources"]:
@@ -154,61 +157,44 @@ class AirflowMesosScheduler(MesosClient):
 
         remaining_cpus = offer_cpus
         remaining_mem = offer_mem
-
-        if remaining_cpus < self.task_cpu:
-            self.log.info("Offered CPU's are not enough: %d, %d, %s", remaining_cpus, self.task_cpu, offer["id"]["value"])
-            return False
-        if remaining_mem < self.task_mem:
-            self.log.info("Offered MEM's are not enough: %d, %d, %s", remaining_mem, self.task_mem, offer["id"]["value"])
-            return False
         
         if (not self.task_queue.empty()):
             key, cmd, executor_config = self.task_queue.get()
             tid = self.task_counter
             self.task_counter += 1
 
-            if executor_config is not None:
-                self.log.debug(executor_config)
-                if "image" in executor_config:
-                    image = executor_config["image"]
-                else:
-                    image = self.mesos_slave_docker_image
+            if "MesosExecutor" in executor_config:
+                self.log.debug("Executor Config: %s", executor_config)
 
-                #                if "command_parameter" in executor_config:
-                #                    command_parameter = executor_config["command_parameter"]
+                self.task_cpu = executor_config["MesosExecutor"].get("cpus", cpu)
+                self.task_mem = executor_config["MesosExecutor"].get("mem_limit", mem)
+                image = executor_config["MesosExecutor"].get("image", self.mesos_slave_docker_image)
+                force_pull = str(executor_config["MesosExecutor"].get("force_pull", "true")).lower()
+                container_type = executor_config["MesosExecutor"].get("container_type", "DOCKER")
+                airflow_task_id = executor_config["MesosExecutor"].get("airflow_task_id", None)
+            else:
+                executor_config = {}
+                executor_config["MesosExecutor"] = {}
+                executor_config["MesosExecutor"]["airflow_task_id"] = None
 
-                if "force_pull" in executor_config:
-                    force_pull = str(executor_config["force_pull"]).lower()
+            if airflow_task_id is not None:
+                # init tasks list for status_update
+                self.tasks[airflow_task_id] = None
+            else:
+                airflow_task_id = "airflow." + str(tid)
 
-                #                if "environment" in executor_config:
-                #                    environment = executor_config["environment"]
+            # set the airflow_task_id as executor config
+            executor_config["MesosExecutor"]["airflow_task_id"] = airflow_task_id
 
-                #                if "secret_environment" in executor_config:
-                #                    secret_environment = executor_config["secret_environment"]
-
-                #                if "cpus" in executor_config:
-                #                    cpus = executor_config["cpus"]
-
-                #                if "memlimit" in executor_config:
-                #                    memlimit = executor_config["memlimit"]
-
-                #                if "gpus" in executor_config:
-                #                    gpus = executor_config["gpus"]
-
-                #                if "network_mode" in executor_config:
-                #                    network_mode = executor_config["network_mode"]
-
-                if "container_type" in executor_config:
-                    container_type = executor_config["container_type"]
-
-                if "airflow_task_id" in executor_config:
-                    airflow_task_id = executor_config["airflow_task_id"]
-
-                if airflow_task_id is not None:
-                    # init tasks list for status_update
-                    self.tasks[airflow_task_id] = None
-                else:
-                    airflow_task_id = "airflow." + str(tid)
+            # if the resources does not match, add the task again
+            if float(remaining_cpus) < float(self.task_cpu):
+                self.log.info("Offered CPU's for task %d are not enough: got: %d need: %d - %s", tid, remaining_cpus, self.task_cpu, offer["id"]["value"])
+                self.task_queue.put((key, cmd, executor_config))
+                return False
+            if float(remaining_mem) < float(self.task_mem):
+                self.log.info("Offered MEM's for task %d are not enough: got: %d need: %d - %s", tid, remaining_mem, self.task_mem, offer["id"]["value"])
+                self.task_queue.put((key, cmd, executor_config))
+                return False
 
             self.task_key_map[airflow_task_id] = key
 
@@ -522,6 +508,7 @@ class MesosExecutor(BaseExecutor):
             methods=["GET"],
         )
 
+
         Thread(target=serve, args=[app], daemon=True, kwargs={"port": "10000"}).start()
 
     def sync(self) -> None:
